using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using Microsoft.SharePoint;

namespace DemoEventHandler
{
    public class Demo : SPItemEventReceiver
    {
        const int MaxFileSize = 5000; //Taille maximale de 5kb      


        /// <summary>
        /// Ce document est dclench lorsque le document est en passe d'tre ajout  la liste
        /// </summary>
        /// <param name="properties"></param>
        public override void ItemAdding(SPItemEventProperties properties)
        {
            //Capture de la taille du fichier upload
            int ItemFileSize = Convert.ToInt16(properties.AfterProperties["vti_filesize"].ToString());
            //Si elle dpasse la taille maximale autorise
            if (ItemFileSize > MaxFileSize)
            {
                //On affiche un message d'erreur
                properties.ErrorMessage = "Le fichier que vous tentez de charger dans la liste est trop gros, max " +
                    MaxFileSize.ToString();
                //On annule l'opration, l'lment ne sera donc pas ajout.
                properties.Cancel = true;
            }

        }
        /// <summary>
        /// Cet vnement est dclench lorsque le document a t ajout  la liste.
        /// </summary>
        /// <param name="properties"></param>
        public override void ItemAdded(SPItemEventProperties properties)
        {
            //Construction de l'annonce en rcuprant les proprits Name et l'URL du document upload.
            StringBuilder MessageBody = new StringBuilder();
            MessageBody.Append("Le document ");
            MessageBody.Append(properties.ListItem["Name"]);
            MessageBody.Append(" cr par ");
            MessageBody.Append(properties.ListItem["Created By"]);
            MessageBody.Append(" est disponible <a href='");
            MessageBody.Append(properties.ListItem["EncodedAbsUrl"]);
            MessageBody.Append("'>ici</a>");            
            AddToList("Announcements", MessageBody,properties.WebUrl,"Body","Nouveau document!");            
        }
       
        /// <summary>
        /// Cet vnement est dclench lorsqu'un document est supprim
        /// </summary>
        /// <param name="properties"></param>
        public override void ItemDeleted(SPItemEventProperties properties)
        {
            //Ajout d'un lment dans la table AuditDocs qui dit quel document a t supprim et par qui
            StringBuilder MessageBody = new StringBuilder();
            MessageBody.Append("L'lment ");
            MessageBody.Append(properties.ListItemId);
            MessageBody.Append(" ");
            MessageBody.Append(properties.BeforeUrl);
            MessageBody.Append(" a t supprim par ");
            MessageBody.Append(properties.UserDisplayName);
            AddToList("AuditDocs",MessageBody,properties.WebUrl,"Title","");
        }        
        /// <summary>
        /// Ajout d'un lment dans la liste "ListName"
        /// </summary>
        /// <param name="ListName"></param>
        /// <param name="Message"></param>
        /// <param name="Url"></param>
        /// <param name="FieldName"></param>
        /// <param name="Title"></param>
        private void AddToList(string ListName,StringBuilder Message, string Url,string FieldName,string Title)
        {
            SPSite Site = null;
            SPWeb Web = null;
            try
            {
                Site = new SPSite(Url);
                Web = Site.OpenWeb();
                SPList AuditList = Web.Lists[ListName];
                
                SPListItem AuditItem = AuditList.Items.Add();
                if (Title != String.Empty)
                {
                    AuditItem["Title"] = Title;
                }
                AuditItem[FieldName] = Message.ToString();
                AuditItem.Update();
            }
            finally
            {
                if (Web != null)
                    Web.Close();
                if (Site != null)
                    Site.Close();
            }
        }
       
    }
    
}
